/***************************************************************
From the book "Motif Programming, The Essentials...and More"
by Marshall Brain.
Published by Digital Press, ISBN 1-55558-089-0.
To order the book, call 1-800-DIGITAL and ask for EY-J816E-DP.

Copyright 1992, by Digital Equipment Corp.

This code demonstrates the drawing area's resize event.
***************************************************************/

/* resize.c */

#include <Xm/Xm.h>
#include <Xm/DrawingA.h>

XtAppContext context;

GC gc;
Widget drawing_area;
Widget toplevel;
XSegment lines[2];
int num_lines=2;

void setup_gc()
/* set up the graphics context. */
{
    int foreground,background;
    XGCValues vals;
    Arg al[10];
    int ac;

    /* get the current fg and bg colors. */
    ac=0;
    XtSetArg(al[ac], XmNforeground, &foreground); ac++;
    XtSetArg(al[ac], XmNbackground, &background); ac++;
    XtGetValues(drawing_area, al, ac);

    /* create the gc. */
    vals.foreground = foreground;
    vals.background = background;
    gc= XtGetGC(drawing_area, GCForeground | GCBackground, &vals);
}

void exposeCB(w,client_data,call_data)
    Widget w;
    XtPointer client_data;
    XtPointer call_data;
/* called whenever drawing area is exposed. */
{
    printf("exposure event generated\n");
    XDrawSegments(XtDisplay(w),XtWindow(w),gc,lines,num_lines);
}

void resizeCB(w,client_data,call_data)
    Widget w;
    XtPointer client_data;
    XtPointer call_data;   
/* called whenever drawing area is resized. */
{
    Dimension wdth,hght;
    Arg al[10];
    int ac;

    printf("resize event generated\n");

    /* get new window size. */
    ac=0;
    XtSetArg(al[ac],XmNheight,&(hght)); ac++;
    XtSetArg(al[ac],XmNwidth,&(wdth)); ac++;
    XtGetValues(w,al,ac);
    printf("%d %d \n",wdth,hght);

    lines[0].x1 = wdth/2; 
    lines[0].y1 = 0; 
    lines[0].x2 = wdth/2; 
    lines[0].y2 = hght; 

    lines[1].x1 = 0; 
    lines[1].y1 = hght/2; 
    lines[1].x2 = wdth; 
    lines[1].y2 = hght/2; 

    if (XtIsRealized(w))
        XClearArea(XtDisplay(w), XtWindow(w), 0, 0, 0, 0, True); 
}

void main(argc,argv)
    int argc;
    char *argv[];
{
      Arg al[10];
      int ac;

    /* create the toplevel shell */
    toplevel = XtAppInitialize(&context,"",NULL,0,&argc,argv,
        NULL,NULL,0);

    /* set window size. */
    ac=0;
    XtSetArg(al[ac],XmNheight,500); ac++;
    XtSetArg(al[ac],XmNwidth,500); ac++;
    XtSetValues(toplevel,al,ac);

    /* create a drawing area widget. */
    ac=0;
    drawing_area=XmCreateDrawingArea(toplevel,"drawing_area",al,ac);
    XtManageChild(drawing_area);    
    XtAddCallback(drawing_area, XmNexposeCallback, exposeCB, NULL);
    XtAddCallback(drawing_area, XmNresizeCallback, resizeCB, NULL);

    setup_gc();

    XtRealizeWidget(toplevel);
    XtAppMainLoop(context);
}
